uifw/AvKon/aknhlist/inc/akntreelistphysicshandler.h
branchRCL_3
changeset 4 8ca85d2f0db7
parent 0 2f259fa3e83a
child 55 aecbbf00d063
--- a/uifw/AvKon/aknhlist/inc/akntreelistphysicshandler.h	Tue Feb 02 01:00:49 2010 +0200
+++ b/uifw/AvKon/aknhlist/inc/akntreelistphysicshandler.h	Fri Feb 19 23:04:46 2010 +0200
@@ -263,11 +263,11 @@
     TInt WorldHeight();
 
     /**
-     * Returns wheter pointer click is in empty list area.
+     * Returns wheter pointer is in empty list area.
      *
      * @return ETrue if aPosition is in empty list area.
      */    
-    TBool EmptyAreaClicked( TPoint aPosition );
+    TBool PointerOnEmptyArea( TPoint aPosition );
     
 private: // data
 
@@ -403,10 +403,11 @@
     // bottom item in current view, fields count when Y is larger than
     // the last item's Y
     TInt iOldBottomItem; 
+    
     /**
      * ETrue if empty list area is clicked.
      */    
-    TBool iEmptyAreaClicked;
+    TBool iDownOnEmptyArea;
     };
@@ -403,10 +403,11 @@
     /**
-     * ETrue if empty list area is clicked.
+     * ETrue if pointer down on empty list area.
      */    